Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type TestDesc ¶
type TestDesc struct {
Name string
}
TestDesc is used for describing a single test of some test suite. This structure is required by revel test cmd.
type TestResult ¶
TestResult represents the results of running a single test of some test suite. This structure is required by revel test cmd.
type TestRunner ¶
type TestRunner struct {
*revel.Controller
}
TestRunner is a controller which is used for running application tests in browser.
func (TestRunner) Index ¶
func (c TestRunner) Index() revel.Result
Index is an action which renders the full list of available test suites and their tests.
func (TestRunner) List ¶
func (c TestRunner) List() revel.Result
List returns a JSON list of test suites and tests. It is used by revel test command line tool.
type TestSuiteDesc ¶
type TestSuiteDesc struct {
Name string
Tests []TestDesc
// Elem is reflect.Type which can be used for accessing methods
// of the test suite.
Elem reflect.Type
}
TestSuiteDesc is used for storing information about a single test suite. This structure is required by revel test cmd.
type TestSuiteResult ¶
type TestSuiteResult struct {
Name string
Passed bool
Results []TestResult
}
TestSuiteResult stores the results the whole test suite. This structure is required by revel test cmd.